Date: 01 4, 2002 1:03:34 PM

# conceptname

## Purpose

Fetch the string value name of a concept.

## Syntax

returnedString = conceptname(concept)

returnedString - type: str
concept - type: con

## Returns

Name of concept as a string.

## Remarks

You cannot directly print out the name of a concept by referring to its handle, but instead must use this function to access its string valued name. If the concept is bad, an error appears in the log output window.

## Example

@CODE

"output.txt" << conceptname(makeconcept(findroot(),"test"));

Prints out the following in output.txt

test

## See Also

attrname, Knowledge Base Functions